# eric7.QScintilla.Lexers.LexerYAML

Module implementing a YAML lexer with some additional methods.

### Global Attributes

None

### Classes

LexerYAML | Subclass to implement some additional lexer dependant methods.

### Functions

None

## LexerYAML

Subclass to implement some additional lexer dependant methods.

### Derived from

Lexer, QsciLexerYAML

### Class Attributes

None

### Class Methods

None

### Methods

LexerYAML | Constructor
defaultKeywords | Public method to get the default keywords.
initProperties | Public slot to initialize the properties.
isCommentStyle | Public method to check, if a style is a comment style.
isStringStyle | Public method to check, if a style is a string style.

### Static Methods

None

#### LexerYAML (Constructor)

LexerYAML(parent=None)

Constructor

parent
  parent widget of this lexer

#### LexerYAML.defaultKeywords

defaultKeywords(kwSet)

Public method to get the default keywords.

kwSet
  number of the keyword set (integer)

Return:
  string giving the keywords (string) or None

#### LexerYAML.initProperties

initProperties()

Public slot to initialize the properties.

#### LexerYAML.isCommentStyle

isCommentStyle(style)

Public method to check, if a style is a comment style.

style
  style to check (integer)

Return:
  flag indicating a comment style (boolean)

#### LexerYAML.isStringStyle

isStringStyle(style)

Public method to check, if a style is a string style.

style
  style to check (integer)

Return:
  flag indicating a string style (boolean)

Up